package com.ruoyi.project.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.project.domain.TrsPolicyResults;

/**
 * 政治常识监测Service接口
 * 
 * @author ruoyi
 * @date 2025-03-24
 */
public interface ITrsPolicyResultsService 
{
    /**
     * 查询政治常识监测
     * 
     * @param id 政治常识监测主键
     * @return 政治常识监测
     */
    public TrsPolicyResults selectTrsPolicyResultsById(Long id);

    /**
     * 查询政治常识监测列表
     * 
     * @param trsPolicyResults 政治常识监测
     * @return 政治常识监测集合
     */
    public List<TrsPolicyResults> selectTrsPolicyResultsList(TrsPolicyResults trsPolicyResults);

    /**
     * 新增政治常识监测
     * 
     * @param trsPolicyResults 政治常识监测
     * @return 结果
     */
    public int insertTrsPolicyResults(TrsPolicyResults trsPolicyResults);

    /**
     * 修改政治常识监测
     * 
     * @param trsPolicyResults 政治常识监测
     * @return 结果
     */
    public int updateTrsPolicyResults(TrsPolicyResults trsPolicyResults);

    /**
     * 批量删除政治常识监测
     * 
     * @param ids 需要删除的政治常识监测主键集合
     * @return 结果
     */
    public int deleteTrsPolicyResultsByIds(String ids);

    /**
     * 删除政治常识监测信息
     * 
     * @param id 政治常识监测主键
     * @return 结果
     */
    public int deleteTrsPolicyResultsById(Long id);

    Map<String, Integer> getStatistics(TrsPolicyResults trsSensitiveResults);
}
